==> okteta-0.25.2.tar.xz: okteta-0.25.2/kasten/controllers/view/libbytearraychecksum/algorithm/modsumbytearraychecksumparameterset.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MODSUMBYTEARRAYCHECKSUMPARAMETERSET_H
#define MODSUMBYTEARRAYCHECKSUMPARAMETERSET_H

// lib
#include "abstractbytearraychecksumparameterset.h"
#include "endianness.h"

class ModSumByteArrayChecksumParameterSet : public AbstractByteArrayChecksumParameterSet
{
public:
    ModSumByteArrayChecksumParameterSet();
    ~ModSumByteArrayChecksumParameterSet() override;

public: // AbstractByteArrayChecksumParameterSet API
    const char* id() const override;

public:
    void setEndianness(Endianness endianness);

public:
    Endianness endianness() const;

protected:
    Endianness mEndianness = ThisMachineEndianness;
};

#endif

==> okteta-15.08.1.tar.xz: okteta-15.08.1/kasten/controllers/view/libbytearraychecksum/algorithm/modsumbytearraychecksumparameterset.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MODSUMBYTEARRAYCHECKSUMPARAMETERSET_H
#define MODSUMBYTEARRAYCHECKSUMPARAMETERSET_H

// lib
#include "abstractbytearraychecksumparameterset.h"
#include "endianness.h"


class ModSumByteArrayChecksumParameterSet : public AbstractByteArrayChecksumParameterSet
{
  public:
    ModSumByteArrayChecksumParameterSet();
    virtual ~ModSumByteArrayChecksumParameterSet();

  public: // AbstractByteArrayChecksumParameterSet API
    virtual const char* id() const;

  public:
    void setEndianness( Endianness endianness );

  public:
    Endianness endianness() const;

  protected:
    Endianness mEndianness;
};

#endif
